@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2016-02-14'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2016-02-16'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -46,7 +46,7 @@ sub call_lcpan_script {
             or die "lcpan is not available, please install it first\n";
         my $res = Perinci::CmdLine::Call::call_cli_script(
             script => 'lcpan',
-            argv   => ['stats'],
+            argv   => ['stats-last-index-time'],
         );
         die "Can't 'lcpan stats': $res->[0] - $res->[1]\n"
             unless $res->[0] == 200;
@@ -82,7 +82,7 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.07 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-02-14.
+This document describes version 0.08 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-02-16.
 
 =head1 FUNCTIONS
 
